BOOST_PP_SEQ_REPLACE

The BOOST_PP_SEQ_REPLACE macro replaces an element in a seq.

#### Usage

BOOST_PP_SEQ_RPLACE(seq, i, elem)

#### Arguments

seq
  The seq in which an element is to be replaced.
i
  The zero-based position in seq of the element to be replaced. Valid values range from 0 to BOOST_PP_SEQ_SIZE(seq) - 1.
elem
  The element to replace the element at index i within seq.

#### Remarks

This macro returns seq after replacing the element at index i with elem.

#### Requirements

Header: <boost/preprocessor/seq/replace.hpp>

#### Sample Code

    #include <boost/preprocessor/seq/replace.hpp>

    #define SEQ (a)(b)(x)(d)

    BOOST_PP_SEQ_REPLACE(SEQ, 2, c) // expands to (a)(b)(c)(d)

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)